![boiler](docs/files/img/hand-with-envelope.png)
# shift-event


[![Build Status](https://api.travis-ci.org/projectshift/shift-event.svg?branch=master)](https://travis-ci.org/projectshift/shift-event)
[![Coverage Status](https://coveralls.io/repos/github/projectshift/shift-event/badge.svg?branch=master)](https://coveralls.io/github/projectshift/shift-event?branch=master)

Simple event store for event-sourced systems. This still in early beta, not ready for use.
